integration

package
v0.0.0-...-85367c3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 21, 2023 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RunTest

func RunTest(session io.WriteCloser)

RunTest connect to the prompts specified in the integration test script then send the commands for execution. Any error will be detected by the ssh client (cmd/auth.go) on the stderr channel.

Types

type TestAuth

type TestAuth struct {
	Prompts []TestPrompt
}
var TestAuthData TestAuth

TestAuthData stores integration test script data for testing the auth command.

type TestPrompt

type TestPrompt struct {
	Name     string // prompt name
	Matches  string
	Commands []struct {
		Cmd      string // command to execute
		Expected string // expected output
	}
}

TestPrompt and TestAuth represent data loaded from integration test script.

Jump to