Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RunTest ¶
func RunTest(session io.WriteCloser)
RunTest connect to the prompts specified in the integration test script then send the commands for execution. Any error will be detected by the ssh client (cmd/auth.go) on the stderr channel.
Types ¶
type TestAuth ¶
type TestAuth struct {
Prompts []TestPrompt
}
var TestAuthData TestAuth
TestAuthData stores integration test script data for testing the auth command.
Click to show internal directories.
Click to hide internal directories.